document.addEventListener('DOMContentLoaded', () => {
  // Simulated data
  const performanceData = {
    crypto: [10000, 45000, 30000, 60000, 40000],
    gold: [1500, 1600, 1800, 1900, 2000]
  };

  // Initialize metrics
  updateMetrics();
  initializeChart();
  updateRecommendation();

  // Event listeners
  document.getElementById('analyzeBtn').addEventListener('click', () => {
    analyzeCurrentMarket();
  });
});

function updateMetrics() {
  const metrics = {
    volatility: {
      crypto: 85,
      gold: 15
    },
    inflation: {
      crypto: -20,
      gold: 75
    },
    crisis: {
      crypto: 30,
      gold: 90
    }
  };

  document.getElementById('volatilityScore').textContent = `${metrics.volatility.crypto}% / ${metrics.volatility.gold}%`;
  document.getElementById('inflationCorr').textContent = `${metrics.inflation.crypto}% / ${metrics.inflation.gold}%`;
  document.getElementById('crisisScore').textContent = `${metrics.crisis.crypto}% / ${metrics.crisis.gold}%`;
}

function initializeChart() {
  const ctx = document.getElementById('performanceChart');
  if (!ctx) return;

  // Simulate chart drawing with CSS
  ctx.style.height = '300px';
  ctx.style.background = 'linear-gradient(45deg, rgba(255,215,0,0.1), rgba(255,107,107,0.1))';
}

function analyzeCurrentMarket() {
  const button = document.getElementById('analyzeBtn');
  button.textContent = 'Analyzing...';
  button.disabled = true;

  setTimeout(() => {
    updateRecommendation();
    button.textContent = 'Analyze Your Scenario';
    button.disabled = false;
  }, 1500);
}

function updateRecommendation() {
  const recommendation = document.getElementById('recommendationText');
  const currentDate = new Date();
  const marketConditions = getMarketConditions();

  let recommendationText = '';
  if (marketConditions.inflation > 5) {
    recommendationText = 'Current high inflation environment favors gold as a stable store of value.';
  } else if (marketConditions.techGrowth > 7) {
    recommendationText = 'Strong tech growth suggests potential cryptocurrency opportunities.';
  } else {
    recommendationText = 'Consider a balanced approach with both assets based on current market conditions.';
  }

  recommendation.textContent = recommendationText;
}

function getMarketConditions() {
  // Simulated market conditions
  return {
    inflation: Math.random() * 10,
    techGrowth: Math.random() * 10,
    marketVolatility: Math.random() * 100
  };
}

// Add smooth scrolling for navigation
document.querySelectorAll('a[href^="#"]').forEach(anchor => {
  anchor.addEventListener('click', function (e) {
    e.preventDefault();
    document.querySelector(this.getAttribute('href')).scrollIntoView({
      behavior: 'smooth'
    });
  });
});
